@@ -214,6 +214,8 @@ sub nfs_mount
                 return "general error: $message\n" if $file eq '';
                 return "Can't create $file: $message";
         }
+        ($error, $retval) = $self->log_and_exec("mount",$self->cfg->{paths}{prc_nfs_mountdir});
+	return 0 if not $error;
         ($error, $retval) = $self->log_and_exec("mount",$self->cfg->{prc_nfs_server}.":".$self->cfg->{paths}{prc_nfs_mountdir},$self->cfg->{paths}{prc_nfs_mountdir});
         return "Can't mount ".$self->cfg->{paths}{prc_nfs_mountdir}.":$retval" if $error;
         return 0;
